@@ -1,7 +1,8 @@
 package Kelp::Module::Symbiosis::Base;
-$Kelp::Module::Symbiosis::Base::VERSION = '2.00';
+$Kelp::Module::Symbiosis::Base::VERSION = '2.00_01'; # TRIAL
+$Kelp::Module::Symbiosis::Base::VERSION = '2.0001';
 use Kelp::Base qw(Kelp::Module);
-use KelpX::Symbiosis::Util;
+use KelpX::Symbiosis::_Util;
 
 attr -middleware => sub { [] };
 
@@ -14,7 +15,7 @@ sub run
 	my ($self) = shift;
 
 	my $app = $self->psgi(@_);
-	return KelpX::Symbiosis::Util::wrap($self, $app);
+	return KelpX::Symbiosis::_Util::wrap($self, $app);
 }
 
 sub psgi
@@ -29,7 +30,7 @@ sub build
 	die 'Symbiosis needs to be loaded before ' . $self->name
 		unless $self->app->can('symbiosis');
 
-	KelpX::Symbiosis::Util::load_middleware($self, %args);
+	KelpX::Symbiosis::_Util::load_middleware($self, %args);
 
 	$self->app->symbiosis->_link($self->name, $self, $args{mount});
 	return;
