@@ -1,5 +1,6 @@
 package KelpX::Symbiosis::Engine::URLMap;
-$KelpX::Symbiosis::Engine::URLMap::VERSION = '2.00';
+$KelpX::Symbiosis::Engine::URLMap::VERSION = '2.00_01'; # TRIAL
+$KelpX::Symbiosis::Engine::URLMap::VERSION = '2.0001';
 use Kelp::Base 'KelpX::Symbiosis::Engine';
 use Plack::App::URLMap;
 use Carp;
@@ -33,19 +34,6 @@ sub run
 }
 
 1;
-__END__
 
-=head1 NAME
-
-KelpX::Symbiosis::Engine::URLMap - Default engine implementation
-
-=head1 DESCRIPTION
-
-This is a reimplementation of L<KelpX::Symbiosis::Engine> using
-L<Plack::App::URLMap> as a runner. It's pretty straightforward and mounts Kelp
-as just one of the apps in the ecosystem (not giving it any special treatment).
-
-=head1 CAVEATS
-
-=head2 Symbiosis paths will always have priority over Kelp routes
+# This is not internal, but currently no documentation is provided
 
